import { CommonModule } from '@angular/common';
import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';

import { AuthGuard } from '../auth/auth-guard.service';
import { ModifierCategoryListResolver } from '../modifier-categories/modifier-category-list-resolver.service';

import { ModifierDetailComponent } from './modifier-detail/modifier-detail.component';
import { ModifierListComponent } from './modifier-list/modifier-list.component';
import { ModifierListResolver } from './modifier-list-resolver.service';
import { ModifierResolver } from './modifier-resolver.service';

const modifiersRoutes: Routes = [
  {
    path: '',
    component: ModifierListComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Modifiers',
    },
    resolve: {
      list: ModifierListResolver,
      modifierCategories: ModifierCategoryListResolver,
    },
  },
  {
    path: 'new',
    component: ModifierDetailComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Modifiers',
    },
    resolve: {
      item: ModifierResolver,
      modifierCategories: ModifierCategoryListResolver,
    },
  },
  {
    path: ':id',
    component: ModifierDetailComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Modifiers',
    },
    resolve: {
      item: ModifierResolver,
      modifierCategories: ModifierCategoryListResolver,
    },
  },
];

@NgModule({
  imports: [CommonModule, RouterModule.forChild(modifiersRoutes)],
  exports: [RouterModule],
  providers: [ModifierListResolver, ModifierResolver],
})
export class ModifiersRoutingModule {}
