import { CommonModule } from '@angular/common';
import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';

import { AuthGuard } from '../auth/auth-guard.service';
import { MenuCategoryListResolver } from '../menu-category/menu-category-list-resolver.service';
import { SaleCategoryListResolver } from '../sale-category/sale-category-list-resolver.service';

import { ProductDetailComponent } from './product-detail/product-detail.component';
import { ProductListComponent } from './product-list/product-list.component';
import { ProductListResolver } from './product-list-resolver.service';
import { ProductResolver } from './product-resolver.service';

const productsRoutes: Routes = [
  {
    path: '',
    component: ProductListComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Products',
    },
    resolve: {
      list: ProductListResolver,
      menuCategories: MenuCategoryListResolver,
    },
  },
  {
    path: 'new',
    component: ProductDetailComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Products',
    },
    resolve: {
      item: ProductResolver,
      menuCategories: MenuCategoryListResolver,
      saleCategories: SaleCategoryListResolver,
    },
  },
  {
    path: ':id',
    component: ProductDetailComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Products',
    },
    resolve: {
      item: ProductResolver,
      menuCategories: MenuCategoryListResolver,
      saleCategories: SaleCategoryListResolver,
    },
  },
];

@NgModule({
  imports: [CommonModule, RouterModule.forChild(productsRoutes)],
  exports: [RouterModule],
  providers: [ProductListResolver, ProductResolver],
})
export class ProductsRoutingModule {}
